@@ -1,7 +1,7 @@
 /**
 Implementation details (not part of public API).
 
-\file detail.hpp
+\file
 \copyright Copyright 2020. Tom de Geus. All rights reserved.
 \license This project is released under the MIT License.
 */
