@@ -1,7 +1,7 @@
 /**
 Version information.
 
-\file version.h
+\file
 \copyright Copyright 2020. Tom de Geus. All rights reserved.
 \license This project is released under the MIT License.
 */
@@ -26,12 +26,12 @@ Either:
 
     From the root of this project. This is what ``setup.py`` does.
 
-Note that both ``CMakeLists.txt`` and ``setup.py`` will construct the version string using
-``setuptools_scm`` **unless** an environment ``PKG_VERSION`` is defined.
-If ``PKG_VERSION`` is defined the version string will be read from that variable.
+Note that both ``CMakeLists.txt`` and ``setup.py`` will construct the version using ``setuptools_scm``.
+Tip: use the environment variable ``SETUPTOOLS_SCM_PRETEND_VERSION``
+to overwrite the automatic version.
 */
 #ifndef GMATTENSOR_VERSION
-#define GMATTENSOR_VERSION "0.6.0"
+#define GMATTENSOR_VERSION "0.7.0"
 #endif
 
 namespace GMatTensor {
